# Use IPv4 or IPv6 protocols to reach the provider
IP_V4=4
IP_V6=6

# Use DNS or HTTP protocols to reach the provider
PROTO_DNS  = 1
PROTO_HTTP = 2
PROTO_STUNS = 3
PROTO_STR = {1: "DNS", 2: "HTTP", 3: "STUNS"}

# Providers by type
ALL_PROVIDERS = 0
DNS_PROVIDERS = 1
HTTP_PROVIDERS = 2
STUNS_PROVIDERS = 3
